#include "StdAfx.h"
#include "SyncPreviewAction.h"
#include "NWindowAdapter.h"
#include "PadEditPanel.h"
#include "TipModel.h"
#include "TipView.h"
#include "ScriptletContainerFactory.h"
#include "SimpleEdit.h"

namespace tipuio {

REGISTER_TIPACTION_CREATOR(_T("SyncPreviewAction"), SyncPreviewAction);

SyncPreviewAction::SyncPreviewAction(void)
{
}

SyncPreviewAction::~SyncPreviewAction(void)
{
}
BOOL SyncPreviewAction::ExecuteImpl()
{
	TipModel* model = dynamic_cast<TipModel*>(this->GetModel());
	TipView* view = dynamic_cast<TipView*>(this->GetView());
	if (model == NULL || view == NULL)
	{
		return FALSE;
	}
	PadDocument* padDocument = model->GetPadDocument();
	if (padDocument == NULL) return FALSE;

	if (padDocument->IsEditChanged() == FALSE) return FALSE;

	SimpleEdit* edit = dynamic_cast<SimpleEdit*>(view->FindName(_T("edit_panel")));
	if (edit != NULL)
	{
		CString text = edit->GetText();
		if (text.GetLength() > 0)
		{
			USES_CONVERSION;
			padDocument->SetPreviewRootNode(CT2CA(text));
			
			TiXmlElement* previewNode = padDocument->GetPreviewRootNode();
			CContainer* previewPanel = dynamic_cast<CContainer*>(view->FindName(_T("preview_panel")));
			if (previewNode != NULL && previewPanel != NULL)
			{
				previewPanel->RemoveAll();
				CScriptletContainerFactory::get_instance()->CreateComponent(previewPanel, previewNode);
				previewPanel->RecalcLayout();
				previewPanel->Invalidate();
				previewPanel->GetRootContainer()->RecalcLayout(TRUE);
				previewPanel->GetRootContainer()->Invalidate();
				return TRUE;
			}
		}			
	}
	return FALSE;
}

};